@@ -76,9 +76,9 @@ let%expect_test "leading and trailing whitespace" =
     let columns =
       Ascii_table_kernel.Column.create "comment" to_string
       :: List.map [%all: Comment_print_style.t] ~f:(fun style ->
-        Ascii_table_kernel.Column.create
-          (Comment_print_style.to_string style)
-          (to_string_pretty ~style))
+           Ascii_table_kernel.Column.create
+             (Comment_print_style.to_string style)
+             (to_string_pretty ~style))
     ;;
   end
   in
@@ -102,7 +102,8 @@ let%expect_test "leading and trailing whitespace" =
     │ #| a|#  │ #|.a.|#      │ #|.a|#             │
     │ #|a |#  │ #|.a.|#      │ #|a.|#             │
     │ #| a |# │ #|.a.|#      │ #|.a.|#            │
-    └─────────┴──────────────┴────────────────────┘ |}]
+    └─────────┴──────────────┴────────────────────┘
+    |}]
 ;;
 
 let%expect_test "examples" =
@@ -117,7 +118,8 @@ let%expect_test "examples" =
   [%expect {|
     Pretty_print: #| a b |#
 
-    Conservative_print: #| a  b |# |}];
+    Conservative_print: #| a  b |#
+    |}];
   (* multiple lines *)
   test {| #| a
 b
@@ -132,7 +134,8 @@ b
     b
      c
 
-       d |# |}];
+       d |#
+    |}];
   (* really long comment *)
   test
     {| #| really long comment to see if sexp pretty printing will ever add new line breaks |# |};
@@ -143,7 +146,8 @@ b
        breaks
     |#
 
-    Conservative_print: #| really long comment to see if sexp pretty printing will ever add new line breaks |# |}];
+    Conservative_print: #| really long comment to see if sexp pretty printing will ever add new line breaks |#
+    |}];
   (* comments nested in sexp comment *)
   test
     {| #;
@@ -161,7 +165,8 @@ with
 
     Conservative_print: #;
     ; plain comment#| block comment |#
-    (sexp with #| nested comment |#) |}];
+    (sexp with #| nested comment |#)
+    |}];
   (* quoted newline *)
   test {| #| "quoted
 newline" |# |};
@@ -170,7 +175,8 @@ newline" |# |};
     Pretty_print: #| "quoted newline" |#
 
     Conservative_print: #| "quoted
-    newline" |# |}];
+    newline" |#
+    |}];
   ignore ()
 ;;
 
@@ -179,16 +185,16 @@ let%expect_test "sticky comments" =
     let t = of_string s in
     Config.[ Before; After; Same_line ]
     |> List.iter ~f:(fun sticky ->
-      let label = [%sexp_of: Config.sticky_comments] sticky |> Sexp.to_string in
-      print_endline [%string {|%{label}:|}];
-      List.iter [%all: Comment_print_style.t] ~f:(fun comment_print_style ->
-        let s =
-          let config = get_config ~comment_print_style in
-          let config = { config with Config.sticky_comments = sticky } in
-          List.map t ~f:(Sexp_with_layout.pretty_string config)
-          |> String.concat ~sep:" "
-        in
-        print_endline [%string "%{comment_print_style#Comment_print_style}:\n%{s}"]))
+         let label = [%sexp_of: Config.sticky_comments] sticky |> Sexp.to_string in
+         print_endline [%string {|%{label}:|}];
+         List.iter [%all: Comment_print_style.t] ~f:(fun comment_print_style ->
+           let s =
+             let config = get_config ~comment_print_style in
+             let config = { config with Config.sticky_comments = sticky } in
+             List.map t ~f:(Sexp_with_layout.pretty_string config)
+             |> String.concat ~sep:" "
+           in
+           print_endline [%string "%{comment_print_style#Comment_print_style}:\n%{s}"]))
   in
   test
     {|
@@ -288,7 +294,7 @@ let%expect_test "sticky comments" =
         comment
         |#
     ()))
-      |}];
+    |}];
   ignore ()
 ;;
 
